# setup.py
from setuptools import setup

setup(
    name="pai-sdk",  # Der Name, den du willst
    version="0.0.1",
    description="Reserved for PAI-OS SDK",
    url="https://github.com/aurintex/pai-os",
    author="Aurintex",
    author_email="contact@aurintex.com", # Deine Email
    license="MIT",
    packages=[], # Leer lassen für Reservierung
    install_requires=[],
)
